@@ -16,7 +16,14 @@ abstract class AdapterPdoAbstract extends AdapterAbstract implements LoggerAware
 
     use LoggerAwareTrait;
 
-    /** @var  bool */
+    /**
+     * @var int
+     */
+    private $nestLevel = 0;
+
+    /**
+     * @var bool
+     */
     protected $nestableTransaction = false;
 
     /**
@@ -34,9 +41,6 @@ abstract class AdapterPdoAbstract extends AdapterAbstract implements LoggerAware
      */
     protected $stmtMap;
 
-    /** @var int */
-    private $nestLevel = 0;
-
     /**
      * @param string $dsn
      * @param string $user
@@ -48,12 +52,14 @@ abstract class AdapterPdoAbstract extends AdapterAbstract implements LoggerAware
         $this->dbAccess['dsn'] = $dsn;
         $this->dbAccess['user'] = $user;
         $this->dbAccess['pass'] = $pass;
-        $this->dbAccess['opts'] = array_merge([
-            \PDO::ATTR_ERRMODE => \PDO::ERRMODE_EXCEPTION,
-        ], $opts);
+        $this->dbAccess['opts'] = [
+                \PDO::ATTR_ERRMODE => \PDO::ERRMODE_EXCEPTION,
+            ] + $opts;
         // on utilise une identity map pour stocké les statements afin de les réutiliser
         $this->stmtMap = new IdentityMap();
         $this->logger = new NullLogger();
+        // close handler pour fermeture de la connection
+        register_shutdown_function([$this, 'deconnect']);
     }
 
     /**
@@ -69,7 +75,14 @@ abstract class AdapterPdoAbstract extends AdapterAbstract implements LoggerAware
      */
     public function deconnect()
     {
-        unset($this->dbHandler);
+        if (isset($this->dbHandler)
+            && $this->dbHandler instanceof \PDO
+        ) {
+            $this->logger->info('PDOAdapter DECONNECT', [
+                'access_infos' => $this->dbAccess,
+            ]);
+            unset($this->dbHandler);
+        }
     }
 
     /**
@@ -134,7 +147,7 @@ abstract class AdapterPdoAbstract extends AdapterAbstract implements LoggerAware
                 $this->dbAccess['opts']
             );
             $this->logger->info('PDOAdapter CONNECT TO Database', [
-                'access_infos' => $this->dbAccess
+                'access_infos' => $this->dbAccess,
             ]);
             return true;
         }
